( function () {
	/**
	 * footer object.
	 *
	 * It contains all the functionality related to the footer.
	 *
	 * @since 2.0.0
	 * @type object
	 */
	var footer = {
		/**
		 * Sets, binds, and runs functions.
		 *
		 * @since 2.0.0
		 */
		init: function () {
			this.events = this.events.bind( this );

			this.events();
		},

		/**
		 * Listens for events.
		 *
		 * @since 2.0.0
		 * @listens event:DOMContentLoaded
		 * @listens event:resize
		 */
		events: function () {
			document.addEventListener( 'DOMContentLoaded', this.positionFooter );
			window.addEventListener( 'resize', this.positionFooter );
		},

		/**
		 * Positions the footer according to the contents of the document.
		 *
		 * @since 2.0.0
		 */
		positionFooter: function () {
			var footerEl = document.querySelector( '#gf-footer' );

			if ( window.innerHeight >= document.body.scrollHeight ) {
				footerEl.style.position = 'absolute';
				footerEl.style.right = '0';
				footerEl.style.bottom = '0';
				footerEl.style.left = '0';
			} else if ( window.innerHeight < document.body.scrollHeight ) {
				footerEl.style.position = 'static';
			}
		}
	};

	footer.init();
} )();
