<?php

if ( ! function_exists( 'go_first_setup_theme' ) ) {
	/**
	 * Enables more customization settings and enables support for native functionality.
	 *
	 * This allows the customization of:
	 * - Custom logo.
	 * - Custom header.
	 * - Custom background.
	 * 
	 * This theme enables support for:
	 * - Title.
	 * - Post thumbnails.
	 * - Feed links.
	 * - Internationalization.
	 * 
	 * @since 1.0.0
	 */
	function go_first_setup_theme() {
		// Custom Logo
		$custom_logo_defaults = array(
			'flex-height' => true,
			'flex-width'  => true,
		);

		add_theme_support( 'custom-logo', $custom_logo_defaults );

		// Custom Header
		$custom_header_defaults = array(
			'height'      => '70',
			'flex-height' => true,
			'flex-width'  => true,
			'width'       => '1920',
		);

		add_theme_support( 'custom-header', $custom_header_defaults );

		// Custom Background
		$custom_background_defaults = array(
			'default-image'          => '',
			'default-color'          => 'FFF',
			'default-attachment'     => 'fixed',
			'default-position-x'     => 'center',
			'default-repeat'         => 'no-repeat',
		);

		add_theme_support( 'custom-background', $custom_background_defaults );

		// Title
		add_theme_support( 'title-tag' );

		// Post Thumbnails
		add_theme_support( 'post-thumbnails' );

		// Feed Links
		add_theme_support( 'automatic-feed-links' );
		
		// Text Domain
		load_theme_textdomain( 'go-first', get_template_directory() . '/languages' );
	}

	// after_setup_theme action hook.
	add_action( 'after_setup_theme', 'go_first_setup_theme' );
}
