<?php

if ( ! function_exists( 'go_first_wp_head' ) ) {
    /**
     * Calls all the functions to be run during the wp_head action hook.
     *
     * @since 1.3.0
     * @since 2.0.0 Added call to the go_first_set_primary_and_secondary_theme_colors function.
     */
    function go_first_wp_head() {
        go_first_header_textcolor();
        go_first_header_image();
        go_first_set_primary_and_secondary_theme_colors();
    }

    // wp_head action hook.
    add_action( 'wp_head', 'go_first_wp_head' );
}

if ( ! function_exists( 'go_first_header_textcolor' ) ) {
    /** 
     * Checks if header text color is set and applies it.
     * 
     * @since 1.3.0
     * @since 2.0.0 Added media query rules to style links from dropdown menus.
     */
    function go_first_header_textcolor() {
        $header_textcolor = get_header_textcolor();
        
        if ( ! empty( $header_textcolor ) ) {
            ?>
                <style type="text/css">
                    .gf-navbar .nav-item > a {
                        color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                    }

                    @media (max-width: 1199px) {
                        .gf-navbar.navbar-expand-xl .dropdown-menu a {
                            color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                        }
                    }

                    @media (max-width: 991px) {
                        .gf-navbar.navbar-expand-lg .dropdown-menu a {
                            color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                        }
                    }

                    @media (max-width: 767px) {
                        .gf-navbar.navbar-expand-md .dropdown-menu a {
                            color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                        }
                    }

                    @media (max-width: 567px) {
                        .gf-navbar.navbar-expand-sm .dropdown-menu a {
                            color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                        }
                    }
                </style>
            <?php
        }
    }
}

if ( ! function_exists( 'go_first_header_image' ) ) {
    /** 
     * Checks if header image is set and applies it.
     * 
     * @since 1.3.0
     */
    function go_first_header_image() {
        $header_image_data = get_theme_mod( 'header_image_data' );
        
        if ( ! empty( $header_image_data ) ) {
            ?>
                <style type="text/css">
                    .gf-navbar {
                        background-image: url(<?php echo esc_url( get_theme_mod( 'header_image' ) ); ?>);
                        background-repeat: no-repeat;
                        background-position: center center;
                        background-size: cover;
                    }
                </style>
            <?php
        }
    }
}

if ( ! function_exists( 'go_first_set_primary_and_secondary_theme_colors' ) ) {
    /**
     * Sets the primary and secondary theme colors established via the Customizer using javascript.
     *
     * @since 2.0.0
     */
    function go_first_set_primary_and_secondary_theme_colors() {
        $primary_color      = get_theme_mod( 'primary_color', '' );
        $secondary_color    = get_theme_mod( 'secondary_color', '' );

        ?>
            <!-- <![CDATA[ -->
            <script>
                var goFirstColors = { primary: <?php echo json_encode( $primary_color ); ?>, secondary: <?php echo json_encode( $secondary_color ) ?> };
            </script>
            <!-- ]]> -->
            <script>
                ( function () {
                    if ( undefined !== window.goFirstColors.primary && "" !== window.goFirstColors.primary ) {
                        document.documentElement.style.setProperty( '--color-primary', window.goFirstColors.primary );
                    }

                    if ( undefined !== window.goFirstColors.secondary && "" !== window.goFirstColors.secondary ) {
                        document.documentElement.style.setProperty( '--color-secondary', window.goFirstColors.secondary );
                    }
                } )();
            </script>
        <?php
    }
}
